andrei          Tue Feb 20 06:23:03 2001 EDT

  Modified files:              
    /php4/ext/standard  array.c basic_functions.c php_array.h 
  Log:
  Rename to array_search().
  
  
Index: php4/ext/standard/basic_functions.c
diff -u php4/ext/standard/basic_functions.c:1.306 
php4/ext/standard/basic_functions.c:1.307
--- php4/ext/standard/basic_functions.c:1.306   Mon Feb 19 21:36:40 2001
+++ php4/ext/standard/basic_functions.c Tue Feb 20 06:23:03 2001
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: basic_functions.c,v 1.306 2001/02/20 05:36:40 jason Exp $ */
+/* $Id: basic_functions.c,v 1.307 2001/02/20 14:23:03 andrei Exp $ */
 
 #include "php.h"
 #include "php_main.h"
@@ -550,7 +550,7 @@
        PHP_FE(min,                                                                    
         NULL)
        PHP_FE(max,                                                                    
         NULL)
        PHP_FE(in_array,                                                               
 NULL)
-       PHP_FE(search_array,                                                           
 NULL)
+       PHP_FE(array_search,                                                    NULL)
        PHP_FE(extract,                                                                
 NULL)
        PHP_FE(compact,                                                                
 NULL)
        PHP_FE(range,                                                                  
 NULL)
Index: php4/ext/standard/php_array.h
diff -u php4/ext/standard/php_array.h:1.19 php4/ext/standard/php_array.h:1.20
--- php4/ext/standard/php_array.h:1.19  Mon Feb 19 21:36:40 2001
+++ php4/ext/standard/php_array.h       Tue Feb 20 06:23:03 2001
@@ -19,7 +19,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: php_array.h,v 1.19 2001/02/20 05:36:40 jason Exp $ */
+/* $Id: php_array.h,v 1.20 2001/02/20 14:23:03 andrei Exp $ */
 
 #ifndef PHP_ARRAY_H
 #define PHP_ARRAY_H
@@ -49,7 +49,7 @@
 PHP_FUNCTION(min);
 PHP_FUNCTION(max);
 PHP_FUNCTION(in_array);
-PHP_FUNCTION(search_array);
+PHP_FUNCTION(array_search);
 PHP_FUNCTION(extract);
 PHP_FUNCTION(compact);
 PHP_FUNCTION(range);



Index: php4/ext/standard/array.c
diff -u php4/ext/standard/array.c:1.92 php4/ext/standard/array.c:1.93
--- php4/ext/standard/array.c:1.92      Mon Feb 19 21:36:40 2001
+++ php4/ext/standard/array.c   Tue Feb 20 06:23:03 2001
@@ -21,7 +21,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: array.c,v 1.92 2001/02/20 05:36:40 jason Exp $ */
+/* $Id: array.c,v 1.93 2001/02/20 14:23:03 andrei Exp $ */
 
 #include "php.h"
 #include "php_ini.h"
@@ -1107,12 +1107,11 @@
                zend_hash_move_forward_ex(target_hash, &pos);
        }
    
-       if (behavior == 0) { 
-               RETURN_FALSE;      
+       if (behavior == 0) {
+               RETURN_FALSE;
        } else { 
                return;
        }
-       
 }
 
 
@@ -1124,9 +1123,9 @@
 }
 /* }}} */
 
 /* {{{ proto mixed search_array(mixed needle, array haystack [, bool strict])
    Searches the array for a given value and returns the corresponding key if 
successful */
-PHP_FUNCTION(search_array)
+PHP_FUNCTION(array_search)
 {
        php_search_array(INTERNAL_FUNCTION_PARAM_PASSTHRU, 1);
 }
@@ -1124,9 +1123,9 @@
 /* }}} */
 
-/* {{{ proto mixed search_array(mixed needle, array haystack [, bool strict])
+/* {{{ proto mixed array_search(mixed needle, array haystack [, bool strict])
    Searches the array for a given value and returns the corresponding key if 
successful */
-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
To contact the list administrators, e-mail: [EMAIL PROTECTED]

Reply via email to